==> jc-1.4.0.tar.gz: javax/swing/text/DefaultEditorKit__24InsertContentAction.h <==
// public class javax.swing.text.DefaultEditorKit$InsertContentAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 416ad719173893f javax_swing_text_DefaultEditorKit__24InsertContentAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *);

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods	javax_swing_text_DefaultEditorKit__24InsertContentAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs	javax_swing_text_DefaultEditorKit__24InsertContentAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24InsertContentAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24InsertContentAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/DefaultEditorKit__24InsertContentAction.h <==
// public class javax.swing.text.DefaultEditorKit$InsertContentAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 6923d5b9a4bc7c8b javax_swing_text_DefaultEditorKit__24InsertContentAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vmethods	javax_swing_text_DefaultEditorKit__24InsertContentAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_refs	javax_swing_text_DefaultEditorKit__24InsertContentAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24InsertContentAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$vtype _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24InsertContentAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24InsertContentAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24InsertContentAction_H_ */
